@@ -1,6 +1,6 @@
 package App::JobLog::Command::summary;
 BEGIN {
-  $App::JobLog::Command::summary::VERSION = '1.014';
+  $App::JobLog::Command::summary::VERSION = '1.015';
 }
 
 # ABSTRACT: show what you did during a particular period
@@ -117,7 +117,7 @@ sub execute {
         # figure out how wide to make things
         my $screen_width;
         if ( $opt->{wrap} ) {
-            if ( $opt->no_wrap ) {
+            if ( $opt->{no_wrap} ) {
                 $screen_width = -1;
             }
             else {
@@ -429,7 +429,7 @@ App::JobLog::Command::summary - show what you did during a particular period
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 SYNOPSIS
 
